@@ -1,31 +1,36 @@
-/// In charge of cleaning, processing, and managing data.  I couldn't think of
-/// a better name for the file.  Since I called data collection "harvesting",
-/// then this is the farmer I guess.
-///
-/// Essentially the main goal is to shift the initial calculation and distribution
-/// of joiner points and data to one central location that will only do it
-/// *once* upon receiving the data --- as opposed to doing it on canvas draw,
-/// which will be a costly process.
-///
-/// This will also handle the *cleaning* of stale data.  That should be done
-/// in some manner (timer on another thread, some loop) that will occasionally
-/// call the purging function.  Failure to do so *will* result in a growing
-/// memory usage and higher CPU usage - you will be trying to process more and
-/// more points as this is used!
+//! In charge of cleaning, processing, and managing data.  I couldn't think of
+//! a better name for the file.  Since I called data collection "harvesting",
+//! then this is the farmer I guess.
+//!
+//! Essentially the main goal is to shift the initial calculation and distribution
+//! of joiner points and data to one central location that will only do it
+//! *once* upon receiving the data --- as opposed to doing it on canvas draw,
+//! which will be a costly process.
+//!
+//! This will also handle the *cleaning* of stale data.  That should be done
+//! in some manner (timer on another thread, some loop) that will occasionally
+//! call the purging function.  Failure to do so *will* result in a growing
+//! memory usage and higher CPU usage - you will be trying to process more and
+//! more points as this is used!
+
+use std::{collections::BTreeMap, time::Instant, vec::Vec};
+
+use fxhash::FxHashMap;
 use once_cell::sync::Lazy;
-
-use std::{time::Instant, vec::Vec};
-
-use crate::{
-    data_harvester::{batteries, cpu, disks, memory, network, processes, temperature, Data},
-    utils::gen_util::{get_decimal_bytes, GIGA_LIMIT},
-};
 use regex::Regex;
 
+#[cfg(feature = "battery")]
+use crate::data_harvester::batteries;
+use crate::{
+    data_harvester::{cpu, disks, memory, network, processes::ProcessHarvest, temperature, Data},
+    utils::gen_util::{get_decimal_bytes, GIGA_LIMIT},
+    Pid,
+};
+
 pub type TimeOffset = f64;
 pub type Value = f64;
 
-#[derive(Debug, Default)]
+#[derive(Debug, Default, Clone)]
 pub struct TimedData {
     pub rx_data: Value,
     pub tx_data: Value,
@@ -33,6 +38,60 @@ pub struct TimedData {
     pub load_avg_data: [f32; 3],
     pub mem_data: Option<Value>,
     pub swap_data: Option<Value>,
+    #[cfg(feature = "zfs")]
+    pub arc_data: Option<Value>,
+    #[cfg(feature = "gpu")]
+    pub gpu_data: Vec<Option<Value>>,
+}
+
+#[derive(Clone, Debug, Default)]
+pub struct ProcessData {
+    /// A PID to process data map.
+    pub process_harvest: BTreeMap<Pid, ProcessHarvest>,
+
+    /// A mapping between a process PID to any children process PIDs.
+    pub process_parent_mapping: FxHashMap<Pid, Vec<Pid>>,
+
+    /// PIDs corresponding to processes that have no parents.
+    pub orphan_pids: Vec<Pid>,
+}
+
+impl ProcessData {
+    fn ingest(&mut self, list_of_processes: Vec<ProcessHarvest>) {
+        self.process_parent_mapping.clear();
+
+        // Reverse as otherwise the pid mappings are in the wrong order.
+        list_of_processes.iter().rev().for_each(|process_harvest| {
+            if let Some(parent_pid) = process_harvest.parent_pid {
+                if let Some(entry) = self.process_parent_mapping.get_mut(&parent_pid) {
+                    entry.push(process_harvest.pid);
+                } else {
+                    self.process_parent_mapping
+                        .insert(parent_pid, vec![process_harvest.pid]);
+                }
+            }
+        });
+
+        self.process_parent_mapping.shrink_to_fit();
+
+        let process_pid_map = list_of_processes
+            .into_iter()
+            .map(|process| (process.pid, process))
+            .collect();
+        self.process_harvest = process_pid_map;
+
+        // We collect all processes that either:
+        // - Do not have a parent PID (that is, they are orphan processes)
+        // - Have a parent PID but we don't have the parent (we promote them as orphans)
+        self.orphan_pids = self
+            .process_harvest
+            .iter()
+            .filter_map(|(pid, process_harvest)| match process_harvest.parent_pid {
+                Some(parent_pid) if self.process_harvest.contains_key(&parent_pid) => None,
+                _ => Some(*pid),
+            })
+            .collect();
+    }
 }
 
 /// AppCollection represents the pooled data stored within the main app
@@ -40,47 +99,56 @@ pub struct TimedData {
 /// collected, and what is needed to convert into a displayable form.
 ///
 /// If the app is *frozen* - that is, we do not want to *display* any changing
-/// data, keep updating this, don't convert to canvas displayable data!
+/// data, keep updating this. As of 2021-09-08, we just clone the current collection
+/// when it freezes to have a snapshot floating around.
 ///
 /// Note that with this method, the *app* thread is responsible for cleaning -
 /// not the data collector.
-#[derive(Debug)]
+#[derive(Debug, Clone)]
 pub struct DataCollection {
     pub current_instant: Instant,
-    pub frozen_instant: Option<Instant>,
     pub timed_data_vec: Vec<(Instant, TimedData)>,
     pub network_harvest: network::NetworkHarvest,
     pub memory_harvest: memory::MemHarvest,
     pub swap_harvest: memory::MemHarvest,
     pub cpu_harvest: cpu::CpuHarvest,
     pub load_avg_harvest: cpu::LoadAvgHarvest,
-    pub process_harvest: Vec<processes::ProcessHarvest>,
+    pub process_data: ProcessData,
     pub disk_harvest: Vec<disks::DiskHarvest>,
     pub io_harvest: disks::IoHarvest,
     pub io_labels_and_prev: Vec<((u64, u64), (u64, u64))>,
     pub io_labels: Vec<(String, String)>,
     pub temp_harvest: Vec<temperature::TempHarvest>,
+    #[cfg(feature = "battery")]
     pub battery_harvest: Vec<batteries::BatteryHarvest>,
+    #[cfg(feature = "zfs")]
+    pub arc_harvest: memory::MemHarvest,
+    #[cfg(feature = "gpu")]
+    pub gpu_harvest: Vec<(String, memory::MemHarvest)>,
 }
 
 impl Default for DataCollection {
     fn default() -> Self {
         DataCollection {
             current_instant: Instant::now(),
-            frozen_instant: None,
             timed_data_vec: Vec::default(),
             network_harvest: network::NetworkHarvest::default(),
             memory_harvest: memory::MemHarvest::default(),
             swap_harvest: memory::MemHarvest::default(),
             cpu_harvest: cpu::CpuHarvest::default(),
             load_avg_harvest: cpu::LoadAvgHarvest::default(),
-            process_harvest: Vec::default(),
+            process_data: Default::default(),
             disk_harvest: Vec::default(),
             io_harvest: disks::IoHarvest::default(),
             io_labels_and_prev: Vec::default(),
             io_labels: Vec::default(),
             temp_harvest: Vec::default(),
+            #[cfg(feature = "battery")]
             battery_harvest: Vec::default(),
+            #[cfg(feature = "zfs")]
+            arc_harvest: memory::MemHarvest::default(),
+            #[cfg(feature = "gpu")]
+            gpu_harvest: Vec::default(),
         }
     }
 }
@@ -92,16 +160,23 @@ impl DataCollection {
         self.memory_harvest = memory::MemHarvest::default();
         self.swap_harvest = memory::MemHarvest::default();
         self.cpu_harvest = cpu::CpuHarvest::default();
-        self.process_harvest = Vec::default();
+        self.process_data = Default::default();
         self.disk_harvest = Vec::default();
         self.io_harvest = disks::IoHarvest::default();
         self.io_labels_and_prev = Vec::default();
         self.temp_harvest = Vec::default();
-        self.battery_harvest = Vec::default();
-    }
-
-    pub fn set_frozen_time(&mut self) {
-        self.frozen_instant = Some(self.current_instant);
+        #[cfg(feature = "battery")]
+        {
+            self.battery_harvest = Vec::default();
+        }
+        #[cfg(feature = "zfs")]
+        {
+            self.arc_harvest = memory::MemHarvest::default();
+        }
+        #[cfg(feature = "gpu")]
+        {
+            self.gpu_harvest = Vec::default();
+        }
     }
 
     pub fn clean_data(&mut self, max_time_millis: u64) {
@@ -113,7 +188,7 @@ impl DataCollection {
                 current_time
                     .duration_since(*instant)
                     .as_millis()
-                    .cmp(&(max_time_millis as u128))
+                    .cmp(&(max_time_millis.into()))
                     .reverse()
             }) {
             Ok(index) => index,
@@ -121,12 +196,11 @@ impl DataCollection {
         };
 
         self.timed_data_vec.drain(0..remove_index);
+        self.timed_data_vec.shrink_to_fit();
     }
 
     pub fn eat_data(&mut self, harvested_data: Box<Data>) {
         let harvested_time = harvested_data.last_collection_time;
-        // trace!("Harvested time: {:?}", harvested_time);
-        // trace!("New current instant: {:?}", self.current_instant);
         let mut new_entry = TimedData::default();
 
         // Network
@@ -139,12 +213,26 @@ impl DataCollection {
             self.eat_memory_and_swap(memory, swap, &mut new_entry);
         }
 
+        #[cfg(feature = "zfs")]
+        {
+            if let Some(arc) = harvested_data.arc {
+                self.eat_arc(arc, &mut new_entry);
+            }
+        }
+
+        #[cfg(feature = "gpu")]
+        {
+            if let Some(gpu) = harvested_data.gpu {
+                self.eat_gpu(gpu, &mut new_entry);
+            }
+        }
+
         // CPU
         if let Some(cpu) = harvested_data.cpu {
             self.eat_cpu(cpu, &mut new_entry);
         }
 
-        // Load Average
+        // Load average
         if let Some(load_avg) = harvested_data.load_avg {
             self.eat_load_avg(load_avg, &mut new_entry);
         }
@@ -166,9 +254,12 @@ impl DataCollection {
             self.eat_proc(list_of_processes);
         }
 
-        // Battery
-        if let Some(list_of_batteries) = harvested_data.list_of_batteries {
-            self.eat_battery(list_of_batteries);
+        #[cfg(feature = "battery")]
+        {
+            // Battery
+            if let Some(list_of_batteries) = harvested_data.list_of_batteries {
+                self.eat_battery(list_of_batteries);
+            }
         }
 
         // And we're done eating.  Update time and push the new entry!
@@ -238,7 +329,7 @@ impl DataCollection {
         for (itx, device) in disks.iter().enumerate() {
             if let Some(trim) = device.name.split('/').last() {
                 let io_device = if cfg!(target_os = "macos") {
-                    // Must trim one level further!
+                    // Must trim one level further for macOS!
                     static DISK_REGEX: Lazy<Regex> = Lazy::new(|| Regex::new(r"disk\d+").unwrap());
                     if let Some(disk_trim) = DISK_REGEX.find(trim) {
                         io.get(disk_trim.as_str())
@@ -308,11 +399,29 @@ impl DataCollection {
         self.io_harvest = io;
     }
 
-    fn eat_proc(&mut self, list_of_processes: Vec<processes::ProcessHarvest>) {
-        self.process_harvest = list_of_processes;
+    fn eat_proc(&mut self, list_of_processes: Vec<ProcessHarvest>) {
+        self.process_data.ingest(list_of_processes);
     }
 
+    #[cfg(feature = "battery")]
     fn eat_battery(&mut self, list_of_batteries: Vec<batteries::BatteryHarvest>) {
         self.battery_harvest = list_of_batteries;
     }
+
+    #[cfg(feature = "zfs")]
+    fn eat_arc(&mut self, arc: memory::MemHarvest, new_entry: &mut TimedData) {
+        new_entry.arc_data = arc.use_percent;
+        self.arc_harvest = arc;
+    }
+
+    #[cfg(feature = "gpu")]
+    fn eat_gpu(&mut self, gpu: Vec<(String, memory::MemHarvest)>, new_entry: &mut TimedData) {
+        // Note this only pre-calculates the data points - the names will be
+        // within the local copy of gpu_harvest.  Since it's all sequential
+        // it probably doesn't matter anyways.
+        gpu.iter().for_each(|data| {
+            new_entry.gpu_data.push(data.1.use_percent);
+        });
+        self.gpu_harvest = gpu.to_vec();
+    }
 }
