@@ -1,5 +1,3 @@
-use crate::{app::App, canvas::Painter, constants::*};
-
 use tui::{
     backend::Backend,
     layout::{Constraint, Direction, Layout, Rect},
@@ -8,14 +6,10 @@ use tui::{
     widgets::{Block, Paragraph},
 };
 
-pub trait NetworkBasicWidget {
-    fn draw_basic_network<B: Backend>(
-        &self, f: &mut Frame<'_, B>, app_state: &mut App, draw_loc: Rect, widget_id: u64,
-    );
-}
+use crate::{app::App, canvas::Painter, constants::*};
 
-impl NetworkBasicWidget for Painter {
-    fn draw_basic_network<B: Backend>(
+impl Painter {
+    pub fn draw_basic_network<B: Backend>(
         &self, f: &mut Frame<'_, B>, app_state: &mut App, draw_loc: Rect, widget_id: u64,
     ) {
         let divided_loc = Layout::default()
@@ -44,10 +38,10 @@ impl NetworkBasicWidget for Painter {
             );
         }
 
-        let rx_label = format!("RX: {}", &app_state.canvas_data.rx_display);
-        let tx_label = format!("TX: {}", &app_state.canvas_data.tx_display);
-        let total_rx_label = format!("Total RX: {}", &app_state.canvas_data.total_rx_display);
-        let total_tx_label = format!("Total TX: {}", &app_state.canvas_data.total_tx_display);
+        let rx_label = format!("RX: {}", &app_state.converted_data.rx_display);
+        let tx_label = format!("TX: {}", &app_state.converted_data.tx_display);
+        let total_rx_label = format!("Total RX: {}", &app_state.converted_data.total_rx_display);
+        let total_tx_label = format!("Total TX: {}", &app_state.converted_data.total_tx_display);
 
         let net_text = vec![
             Spans::from(Span::styled(rx_label, self.colours.rx_style)),
